.. _io:

Input/Output Module
===================

.. automodule:: eyetrace.io
   :members:
   :undoc-members:
   :show-inheritance:

The `io` module provides classes and functions for reading video sources
(webcam, video files) and exporting metrics to various formats (CSV, HDF5).

.. toctree::
   :maxdepth: 1
   :caption: Submodules

   io.video
   io.csv_exporter
   io.hdf5_exporter